@@ -12,10 +12,12 @@ admin.site.register(Category, CategoryAdmin)
 class QuestionAdmin(admin.ModelAdmin):
     list_display = [f.name for f in Question._meta.fields]
     list_select_related = True
+    raw_id_fields = ['user']
 admin.site.register(Question, QuestionAdmin)
 
 
 class ResponseAdmin(admin.ModelAdmin):
     list_display = [f.name for f in Response._meta.fields]
     list_select_related = True
+    raw_id_fields = ['user', 'question']
 admin.site.register(Response, ResponseAdmin)
