@@ -1,7 +1,9 @@
 from knowledge import settings
 
+import django
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
+from django.conf import settings as django_settings
 
 from knowledge.managers import QuestionManager, ResponseManager
 from knowledge.signals import knowledge_post_save
@@ -43,7 +45,7 @@ class KnowledgeBase(models.Model):
     added = models.DateTimeField(auto_now_add=True)
     lastchanged = models.DateTimeField(auto_now=True)
 
-    user = models.ForeignKey('auth.User', blank=True,
+    user = models.ForeignKey('auth.User' if django.VERSION < (1, 5, 0) else django_settings.AUTH_USER_MODEL, blank=True,
                              null=True, db_index=True)
     alert = models.BooleanField(default=settings.ALERTS,
         verbose_name=_('Alert'),
@@ -81,11 +83,13 @@ class KnowledgeBase(models.Model):
         Get local name, then self.user's first/last, and finally
         their username if all else fails.
         """
-        name = (self.name or u'{0} {1}'.format(
-            self.user.first_name, self.user.last_name))
-        return name.strip() or self.user.username
+        name = (self.name or (self.user and (
+            u'{0} {1}'.format(self.user.first_name, self.user.last_name).strip()\
+            or self.user.username
+        )))
+        return name.strip() or _("Anonymous")
 
-    get_email = lambda s: s.email or s.user.email
+    get_email = lambda s: s.email or (s.user and s.user.email)
     get_pair = lambda s: (s.get_name(), s.get_email())
     get_user_or_pair = lambda s: s.user or s.get_pair()
 
@@ -120,6 +124,7 @@ class KnowledgeBase(models.Model):
         self.status = status
         if save:
             self.save()
+    switch.alters_data = True
 
     def public(self, save=True):
         self.switch('public', save)
@@ -196,9 +201,9 @@ class Question(KnowledgeBase):
     def get_responses(self, user=None):
         user = user or self._requesting_user
         if user:
-            return [r for r in self.responses.all() if r.can_view(user)]
+            return [r for r in self.responses.all().select_related('user') if r.can_view(user)]
         else:
-            return self.responses.all()
+            return self.responses.all().select_related('user')
 
     def answered(self):
         """
