@@ -1,6 +1,8 @@
 from django.conf import settings
 
 # crowd control
+LOGIN_REQUIRED = getattr(settings, 'KNOWLEDGE_LOGIN_REQUIRED', False)
+LOGIN_URL = getattr(settings, 'LOGIN_URL', '/accounts/login/')
 ALLOW_ANONYMOUS = getattr(settings, 'KNOWLEDGE_ALLOW_ANONYMOUS', False)
 AUTO_PUBLICIZE = getattr(settings, 'KNOWLEDGE_AUTO_PUBLICIZE', False)
 FREE_RESPONSE = getattr(settings, 'KNOWLEDGE_FREE_RESPONSE', True)
